import React, {
  useState,
  useCallback,
  useEffect,
} from 'react';
import ReactDOM from 'react-dom';
import { csv, arc, pie, scaleBand, scaleLinear, max} from 'd3';

const csvUrl =
  'https://gist.githubusercontent.com/1godfrey/e80e47dc0eae58a554237d697cdfd8cd/raw/da351c1029de37a7051e1c7699780b1242d66477/UN_Population_2019.csv';

const width = 960;
const height = 500;

const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    const row = (d) => {
      d.Population = +d['2020'];
      return d;
    };
    csv(csvUrl, row).then(data => {
    	setData(data.slice(0,10));
    });
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }
  console.log(data[0]);

  const yScale = scaleBand()
    .domain(data.map((d) => d.Country))
    .range([0, height]);

  const xScale = scaleLinear()
    .domain([0, max(data, (d) => d.Population)])
    .range([0, width]);
  
  return (
    <svg width={width} height={height}>
      {data.map(d => (
        <rect
          x={0}
          y={yScale(d.Country)}
          width={xScale(d.Population)}
          height={yScale.bandwidth()}
        />
      ))}
    </svg>
  );
};

const rootElement = document.getElementById(
  'root'
);
ReactDOM.render(<App />, rootElement);

//   data.map((d, i) => (
//   <path
//     fill={d['RGB hex value']}
//     d={pieArc({
//       startAngle:
//         (i / data.length) * 2 * Math.PI,
//       endAngle:
//         ((i + 1) / data.length) *
//         2 *
//         Math.PI,
//     })}
//   />
// ))
